@@ -4,9 +4,12 @@ import pytest
 from pydantic import ValidationError
 
 from calkit.models.pipeline import (
+    JsonToLatexStage,
     JuliaCommandStage,
+    JuliaScriptStage,
     JupyterNotebookStage,
     LatexStage,
+    MapPathsStage,
     MatlabCommandStage,
     PythonScriptStage,
     SBatchStage,
@@ -58,9 +61,11 @@ def test_latexstage():
     s = LatexStage(
         name="something", environment="tex", target_path="my-paper.tex"
     )
-    assert " -silent " in s.dvc_cmd
+    assert s.dvc_cmd.startswith("calkit latex build")
+    assert " -e tex " in s.dvc_cmd
+    assert " --verbose " not in s.dvc_cmd
     s.verbose = True
-    assert " -silent " not in s.dvc_cmd
+    assert " --verbose " in s.dvc_cmd
     assert "my-paper.tex" in s.dvc_deps
     assert "my-paper.pdf" in s.dvc_outs
     s = LatexStage(
@@ -146,7 +151,21 @@ def test_juliacommandstage():
     sd = s.to_dvc()
     print(sd)
     assert sd["cmd"] == (
-        'calkit xenv -n j1 --no-check -- "println(\\"sup\\")"'
+        'calkit xenv -n j1 --no-check -- -e "println(\\"sup\\")"'
+    )
+
+
+def test_juliascriptstage():
+    s = JuliaScriptStage(
+        name="script1",
+        environment="julia-env",
+        script_path="scripts/my_script.jl",
+        args=["arg1", "arg2"],
+    )
+    sd = s.to_dvc()
+    print(sd)
+    assert sd["cmd"] == (
+        'calkit xenv -n julia-env --no-check -- "scripts/my_script.jl" arg1 arg2'
     )
 
 
@@ -188,3 +207,45 @@ def test_sbatchstage():
     assert "data/input.txt" in sd["deps"]
     out = {"data/output.txt": {"persist": True}}
     assert out in sd["outs"]
+
+
+def test_mappathsstage():
+    s = MapPathsStage(
+        name="map1",
+        paths=[
+            dict(
+                kind="file-to-file",
+                src="data/input.txt",
+                dest="data/output.txt",
+            ),  # type: ignore
+        ],
+    )
+    sd = s.to_dvc()
+    print(sd)
+    assert sd["cmd"] == (
+        "calkit map-paths --file-to-file 'data/input.txt->data/output.txt'"
+    )
+    assert "data/input.txt" in sd["deps"]
+    assert {"data/output.txt": {"cache": False, "persist": True}} in sd["outs"]
+
+
+def test_jsontolatexstage():
+    s = JsonToLatexStage(
+        name="json2latex",
+        inputs=["data/results.json", "more.json"],
+        outputs=["paper/results.tex", "paper/results2.tex"],
+        command_name="theresults",
+        format={"result1": "{value1:.2f}", "result2": "{value2}"},
+    )
+    sd = s.to_dvc()
+    print(sd)
+    assert sd["cmd"] == (
+        "calkit latex from-json 'data/results.json' 'more.json' "
+        "--output 'paper/results.tex' --output 'paper/results2.tex' "
+        "--command theresults --format-json "
+        '\'{"result1": "{value1:.2f}", "result2": "{value2}"}\''
+    )
+    dvc_outs = s.dvc_outs
+    assert {
+        "paper/results.tex": {"cache": False, "persist": False}
+    } in dvc_outs
